Search is one of the key elements of AIO Launcher. The philosophy of AIO implies that almost any action can be performed using the search feature: launching an app, calling a friend, checking currency rates, or finding information on the internet. This is just a small part of what you can do using the search window.

### Apps Search

- Simply enter part of the app's name to find it.
- Add a space at the end to precisely determine the app's name.
- Search not only covers apps but also includes shortcuts (by their names).
- If search results include only one app, all its shortcuts will also be displayed.
- If an app supports internal search, AIO Launcher will suggest searching directly within it. For example, you can search for the AIO Launcher app on the Play Store by entering `play aio launcher`.
- App search results are sorted by the number of launches.

### Widget Search

Search can provide diverse information, including built-in widgets. Here are some examples of queries:

- `battery` - battery charge level
- `ram` - available RAM
- `nand` - available storage
- `traffic` - used data traffic
- `screen` - screen on time
- `alarm` - time until the next alarm
- `clock` - current time
- `notes` - last three notes
- `tasks` - last three tasks
- `calendar` - last three calendar events
- `exchange` - currency exchange rates
- `player` - current track
- `health` - your health metrics
- `weather` - current weather
- `bitcoin` - Bitcoin exchange rate
- `worldclock` - world clock
- `notify` - last three notifications
- `dialog` - last three conversations
- `feed` - last three news articles
- `control` - control panel
- `finance` - financial widget
- `stopwatch` - stopwatch
- `timer` - timer
- `mail` - last three emails
- `recorder` - voice recorder

Any of these widgets can be added to the screen by tapping the plus icon in the widget's corner.

To find all widgets of a specific app, simply enter its name.

AIO Launcher also supports searching within widgets. For example, the search system will look for every entered string in the notes, tasks, dialogs, notifications, calendar, and news widgets, even if they are not currently displayed on the screen. You can quickly check currency exchange rates by entering something like `100 usd amd` (how much is 100 USD in Armenian Drams) or find the time in a specific city by entering its name (e.g., `paris`).

### Contact Search

- Enter part of the contact's name to call or message them.
- The order of the first and last name does not matter.
- Searches can also be performed by organization name or phone number.

### Action and Setting Search

Using search, you can quickly enable specific modes in AIO Launcher and search through settings. For example:

- `wifi` - Wi-Fi settings
- `nfc` - NFC settings
- `flash` - turn on the flashlight
- `righthand` - enable right-handed mode
- `addnote` - add a note
- `addtask` - add a task
- `quick` - quick settings panel
- `soff` - turn off the screen

The list of switches and actions is extensive and mostly mirrors the functionality of the 'Control Panel' widget and available actions in the AIO Settings -> Actions menu.

### Web Search

Naturally, AIO Launcher can perform internet searches. When you enter a query in the search bar, you'll get a list of suggestions that you can tap to open the browser on the Google page. Alternatively, you can use the search button on the input bar or on the keyboard to find the entered string.

By default, AIO Launcher uses the Google search engine, but you can choose any other search engine in the settings.

Additionally, AIO Launcher supports DuckDuckGo-style bangs. Bangs are a way to perform searches on specific sites or in apps by adding a special prefix to the search query, starting with `!` or `@`. Here are a few examples:

- `!gp aio launcher` - search for AIO Launcher on Google Play Store
- `!m paris` - search for Paris on Google Maps
- `!yt cats` - search for cats on YouTube
- `!w linux` - search for Linux on Wikipedia

There are thousands of similar bangs. You can learn more in the [official DuckDuckGo documentation](https://duckduckgo.com/bangs).

### Calculations and Quick Answers

AIO Launcher includes a Calculator widget, but search can perform more powerful calculations. Just enter `2+3`, and you'll see `5`. Enter `732008/65`, and the launcher will show you the result `11261.661`. AIO Launcher can handle calculations of almost unlimited complexity, such as:

`sin(pi/3)*log(30)/sqrt(0.5)`

*Note for programmers: AIO Launcher features a full-fledged Lua 5.1 interpreter. Therefore, in the search bar, you can not only perform calculations but also use it as an interactive Lua interpreter.*

### ChatGPT

Monthly or yearly subscribers to AIO Launcher also have access to ChatGPT through the search. Simply ask a question in the search bar, and the search will switch to ChatGPT dialogue mode.

If you accidentally close the dialogue window, the last conversation remains in the search history on the screen. Thus, you can always resume the dialogue from where you left off.

If you frequently ask ChatGPT similar questions, you can add them to the quick access menu on the search history screen. Simply enter the question and press the "+" button next to the suggestion to ask ChatGPT. You can delete a question from the menu by long-pressing it.

### Scripts and Plugins

Like AIO Launcher itself, the search engine is extensible. You can add new features through plugins and scripts. For example, the "Calls & SMS" plugin, available for download on the [official website](https://aiolauncher.app), supports searching for recent calls and text messages.

You can also install the [AIO Store](https://play.google.com/store/apps/details?id=ru.execbit.aiostore) app and use it to install search extension scripts. Here are a few examples:

- `Country` - enter the country code in the search bar to find out its name (and vice versa)
- `Password generator` - enter `password` in the search bar to generate a random password
- `QR code` - enter `qr text` in the search bar to encode text into a QR code

If you are a programmer and know Lua, you can write such scripts yourself. The API is straightforward, and all the necessary documentation and examples are available in the [official GitHub repository](https://github.com/zobnin/aiolauncher_scripts).

### Other Search Features

- Search supports transliteration to Cyrillic. This means you can enter `филес` to find `files`.
- The search system ignores any special characters and spaces. This means you can find Play Store by entering `playstore`.
- The search system doesn't differentiate between letters like `a` and `ã`, `e` and `é` and so on.
