local json = require "json"

local mt = {}
local int = {}
local prefs = {}
local file_name = aio:self_name()

function load_file()
    local json_str = files:read_pref(file_name)
    if json_str ~= nil then
        local success, ret = pcall(json.decode, json_str)
        if success then
            int = ret
        end
    end
end

function store_file()
    local json_str = json.encode(int)
    files:write_pref(file_name, json_str)
end

load_file()

mt.__metatable = "locked"

function mt.__index(self, key)
    load_file()
    return int[key]
end

function mt.__newindex(self, key, value)
    if key == "_name" then
        file_name = value
        load_file()
        return
    end

    int[key] = value
    store_file()
end

function mt.__pairs(self)
    return pairs(int)
end

function mt.__ipairs(self)
    return ipairs(int)
end

function mt.__len(self)
    return #int
end

local function serialize(tab, ind)
    ind = ind and (ind .. "   ") or "   "
    local nl = "\n"
    local str = "{" .. nl
    for k, v in pairs(tab) do
        local pr = (type(k)=="string") and ("[\"" .. k .. "\"] = ") or ""
        str = str .. ind .. pr
        if type(v) == "table" then
            str = str .. serialize(v, ind) .. ","
        elseif type(v) == "string" then
            str = str .. "\"" .. tostring(v) .. "\","
        elseif type(v) == "number" or type(v) == "boolean" then
            str = str .. tostring(v) .. ","
        else
            str = str .. "[[" .. tostring(v) .. "]],"
        end
    end
    str = str:gsub(".$","")
    str = str .. nl .. ind .. "}"
    return str
end

function mt.__tostring(self)
   return serialize(int)
end

setmetatable(prefs, mt)

return prefs
