-- Replace the string metatable with a read-only version.
--debug.setmetatable('', {
--   __index = string,
--   __newindex = function() error('table is read only') end,
--   __metatable = false,
--})

-- Disable debug lib
local sb_debug = debug
debug = nil

-- Disable standard libs
package = nil
io = nil
file = nil

-- Disable dangerous os functions
os.execute = nil
os.exit = nil
os.getenv = nil
os.remove = nil
os.rename = nil
os.setlocale = nil
os.tmpname = nil

-- Used to force stop thread from outside
local interrupted = false

function interrupt()
    interrupted = true
end

local function get_file_name(file)
    return file:match("^.+/(.+)$")
end

function coroutine.resume_with_error(co)
    local output = { coroutine.resume(co) }
    if output[1] == false then
        error(output[2], 0)
    end
end

function sandbox(func, arg1, arg2)
    do
        local co = coroutine.create(function() func(arg1, arg2) end)
        local total_stops = 0

        local hook = function()
            total_stops = total_stops + 1

            local info = sb_debug.getinfo(1)
            print("LUA SCRIPT STOPPED "..total_stops.." IN: "..info.source..":"..info.name)

            if interrupted or total_stops >= 100 then
                ui:show_script_crash_dialog(get_file_name(info.source))
                coroutine.yield('resource used too many cycles')
            end
        end

        sb_debug.sethook(co, hook, "", 100000)

        coroutine.resume_with_error(co)
    end

    -- run garbage collection to clean up orphaned threads
	collectgarbage()
end

